pub use std::f64::consts::*;

pub type N = usize;
pub type Z = isize;

pub type R = f64;
pub type C = num_complex::Complex<R>;

pub type M1 = [C; 4];
pub type M2 = [C; 16];